@@ -10,9 +10,9 @@ import logging
 
 from .py27compat import configparser
 
-from keyring import logger
-from keyring import backend
-from keyring.util import platform_ as platform
+from . import logger
+from . import backend
+from .util import platform_ as platform
 
 log = logging.getLogger(__name__)
 
@@ -102,6 +102,10 @@ def load_config():
 
     filename = 'keyringrc.cfg'
 
+    if os.path.exists(filename):
+        warnings.warn("Loading config from the current directory "
+            "(./keyringrc.cfg). This behavior is deprecated and will be "
+            "removed in a future version.")
     local_path = os.path.join(os.getcwd(), filename)
     config_path = os.path.join(platform.config_root(), filename)
 
